using UnityEngine;
using DiskCardGame;
using HarmonyLib;
using Infiniscryption.Core.Helpers;
using InscryptionAPI.Guid;
using Infiniscryption.SideDecks.Sigils;
using InscryptionAPI.Card;
using Infiniscryption.SideDecks;
using System.Collections.Generic;
using System.Linq;
using Infiniscryption.PackManagement;
using System;
using InscryptionAPI.Helpers;

namespace Infiniscryption.SideDecks.Patchers
{
    public static class CustomCards
    {
        public static readonly List<Ability> sideDeckableAbilities = new List<Ability>() {
            Ability.GainGemGreen, GainGemOrange, GainGemBlue
        };

        private static void RegisterMetacategoriesInner()
        {
            PackManager.AddProtectedMetacategory(SideDeckManager.SIDE_DECK);
        }

        private static void RegisterMetacategories()
        {
            try
            {
                RegisterMetacategoriesInner();
            }
            catch (Exception)
            {
                SideDecksPlugin.Log.LogInfo($"Error registering pack manager exception - pack manager plugin not loaded. This is not a problem.");
            }
        }

        internal static void RegisterCustomCards(Harmony harmony)
        {
            // Register the sigils
            RegisterCustomAbilities(harmony);

            // Register the protected metacategories
            RegisterMetacategories();

            // Update all of the old style side deck cards
            CardManager.ModifyCardList += delegate(List<CardInfo> cards)
            {
                foreach (CardInfo card in cards.Where(c => c.HasTrait(SideDeckManager.BACKWARDS_COMPATIBLE_SIDE_DECK_MARKER)))
                {
                    card.SetSideDeck(card.temple, 10);
                    card.traits.Remove(SideDeckManager.BACKWARDS_COMPATIBLE_SIDE_DECK_MARKER);
                }

                return cards;
            };

            // me trying to add mox vessels
            CardManager.New(SideDecksPlugin.CardPrefix,
                    "MoxVessel",
                    "Mox Vessel",
                    0, 1,
                    "Vessels that give Mox Gems.")
                .SetSideDeck(CardTemple.Tech, 15)
                .SetPortrait(Resources.Load<Texture2D>("art/cards/portraits/IGCC_Mox_Vessel.png"))
                .SetPixelPortrait(Resources.Load<Texture2D>("art/gbc/cards/pixelportraits/Mox_Vessel_Pixel.png"))
                .AddAbilities(Ability.GainGemGreen, GainGemOrange, GainGemBlue);
        }
    }
}
{
    public static class CustomCards
    {
        public static readonly List<Ability> sideDeckableAbilities = new List<Ability>() {
            Ability.GainGemGreen
        };

        private static void RegisterMetacategoriesInner()
        {
            PackManager.AddProtectedMetacategory(SideDeckManager.SIDE_DECK);
        }

        private static void RegisterMetacategories()
        {
            try
            {
                RegisterMetacategoriesInner();
            }
            catch (Exception)
            {
                SideDecksPlugin.Log.LogInfo($"Error registering pack manager exception - pack manager plugin not loaded. This is not a problem.");
            }
        }

        internal static void RegisterCustomCards(Harmony harmony)
        {
            // Register the sigils
            RegisterCustomAbilities(harmony);

            // Register the protected metacategories
            RegisterMetacategories();

            // Update all of the old style side deck cards
            CardManager.ModifyCardList += delegate(List<CardInfo> cards)
            {
                foreach (CardInfo card in cards.Where(c => c.HasTrait(SideDeckManager.BACKWARDS_COMPATIBLE_SIDE_DECK_MARKER)))
                {
                    card.SetSideDeck(card.temple, 10);
                    card.traits.Remove(SideDeckManager.BACKWARDS_COMPATIBLE_SIDE_DECK_MARKER);
                }

                return cards;
            };

            // me trying to add mox vessels
            CardManager.New(SideDecksPlugin.CardPrefix,
                    "GreenVessel",
                    "Green Vessel",
                    0, 1,
                    "Vessels that give green Mox Gems.")
                .SetSideDeck(CardTemple.Tech, 5)
                .SetPortrait(Resources.Load<Texture2D>("art/cards/portraits/Mox_Green.png"))
                .SetPixelPortrait(Resources.Load<Texture2D>("art/gbc/cards/pixelportraits/Pixel_Mox_Green.png"))
                .AddAbilities(Ability.GainGemGreen);
        }
    }
}
{
    public static class CustomCards
    {
        public static readonly List<Ability> sideDeckableAbilities = new List<Ability>() {
            Ability.GainGemOrange
        };

        private static void RegisterMetacategoriesInner()
        {
            PackManager.AddProtectedMetacategory(SideDeckManager.SIDE_DECK);
        }

        private static void RegisterMetacategories()
        {
            try
            {
                RegisterMetacategoriesInner();
            }
            catch (Exception)
            {
                SideDecksPlugin.Log.LogInfo($"Error registering pack manager exception - pack manager plugin not loaded. This is not a problem.");
            }
        }

        internal static void RegisterCustomCards(Harmony harmony)
        {
            // Register the sigils
            RegisterCustomAbilities(harmony);

            // Register the protected metacategories
            RegisterMetacategories();

            // Update all of the old style side deck cards
            CardManager.ModifyCardList += delegate(List<CardInfo> cards)
            {
                foreach (CardInfo card in cards.Where(c => c.HasTrait(SideDeckManager.BACKWARDS_COMPATIBLE_SIDE_DECK_MARKER)))
                {
                    card.SetSideDeck(card.temple, 10);
                    card.traits.Remove(SideDeckManager.BACKWARDS_COMPATIBLE_SIDE_DECK_MARKER);
                }

                return cards;
            };

            // me trying to add orange mox vessels
            CardManager.New(SideDecksPlugin.CardPrefix,
                    "OrangeVessel",
                    "Orange Vessel",
                    0, 1,
                    "Vessels that give orange Mox Gems.")
                .SetSideDeck(CardTemple.Tech, 5)
                .SetPortrait(Resources.Load<Texture2D>("art/cards/portraits/Mox_Orange.png"))
                .SetPixelPortrait(Resources.Load<Texture2D>("art/gbc/cards/pixelportraits/Pixel_Mox_Orange.png"))
                .AddAbilities(Ability.GainGemOrange);
        }
    }
}
{
    public static class CustomCards
    {
        public static readonly List<Ability> sideDeckableAbilities = new List<Ability>() {
            Ability.GainGemBlue, GainGemGreen
        };

        private static void RegisterMetacategoriesInner()
        {
            PackManager.AddProtectedMetacategory(SideDeckManager.SIDE_DECK);
        }

        private static void RegisterMetacategories()
        {
            try
            {
                RegisterMetacategoriesInner();
            }
            catch (Exception)
            {
                SideDecksPlugin.Log.LogInfo($"Error registering pack manager exception - pack manager plugin not loaded. This is not a problem.");
            }
        }

        internal static void RegisterCustomCards(Harmony harmony)
        {
            // Register the sigils
            RegisterCustomAbilities(harmony);

            // Register the protected metacategories
            RegisterMetacategories();

            // Update all of the old style side deck cards
            CardManager.ModifyCardList += delegate(List<CardInfo> cards)
            {
                foreach (CardInfo card in cards.Where(c => c.HasTrait(SideDeckManager.BACKWARDS_COMPATIBLE_SIDE_DECK_MARKER)))
                {
                    card.SetSideDeck(card.temple, 10);
                    card.traits.Remove(SideDeckManager.BACKWARDS_COMPATIBLE_SIDE_DECK_MARKER);
                }

                return cards;
            };

            // me trying to add mox vessels
            CardManager.New(SideDecksPlugin.CardPrefix,
                    "BleenVessel",
                    "Bleen Vessel",
                    0, 1,
                    "Vessels that give green and blue Mox Gems.")
                .SetSideDeck(CardTemple.Tech, 10)
                .SetPortrait(Resources.Load<Texture2D>("art/cards/portraits/Mox_Green_Blue.png"))
                .SetPixelPortrait(Resources.Load<Texture2D>("art/gbc/cards/pixelportraits/Mox_Green_Blue_Pixel.png"))
                .AddAbilities(Ability.GainGemBlue, GainGemGreen);
        }
    }
}
{
    public static class CustomCards
    {
        public static readonly List<Ability> sideDeckableAbilities = new List<Ability>() {
            Ability.GainGemBlue
        };

        private static void RegisterMetacategoriesInner()
        {
            PackManager.AddProtectedMetacategory(SideDeckManager.SIDE_DECK);
        }

        private static void RegisterMetacategories()
        {
            try
            {
                RegisterMetacategoriesInner();
            }
            catch (Exception)
            {
                SideDecksPlugin.Log.LogInfo($"Error registering pack manager exception - pack manager plugin not loaded. This is not a problem.");
            }
        }

        internal static void RegisterCustomCards(Harmony harmony)
        {
            // Register the sigils
            RegisterCustomAbilities(harmony);

            // Register the protected metacategories
            RegisterMetacategories();

            // Update all of the old style side deck cards
            CardManager.ModifyCardList += delegate(List<CardInfo> cards)
            {
                foreach (CardInfo card in cards.Where(c => c.HasTrait(SideDeckManager.BACKWARDS_COMPATIBLE_SIDE_DECK_MARKER)))
                {
                    card.SetSideDeck(card.temple, 10);
                    card.traits.Remove(SideDeckManager.BACKWARDS_COMPATIBLE_SIDE_DECK_MARKER);
                }

                return cards;
            };

            // me trying to add mox vessels
            CardManager.New(SideDecksPlugin.CardPrefix,
                    "BlueVessel",
                    "Blue Vessel",
                    0, 1,
                    "Vessels that give blue Mox Gems.")
                .SetSideDeck(CardTemple.Tech, 5)
                .SetPortrait(Resources.Load<Texture2D>("art/cards/portraits/Mox_Blue.png"))
                .SetPixelPortrait(Resources.Load<Texture2D>("art/gbc/cards/pixelportraits/Pixel_Mox_Blue.png"))
                .AddAbilities(Ability.GainGemBlue);
        }
    }
}
{
    public static class CustomCards
    {
        public static readonly List<Ability> sideDeckableAbilities = new List<Ability>() {
            Ability.GainGemBlue, GainGemOrange
        };

        private static void RegisterMetacategoriesInner()
        {
            PackManager.AddProtectedMetacategory(SideDeckManager.SIDE_DECK);
        }

        private static void RegisterMetacategories()
        {
            try
            {
                RegisterMetacategoriesInner();
            }
            catch (Exception)
            {
                SideDecksPlugin.Log.LogInfo($"Error registering pack manager exception - pack manager plugin not loaded. This is not a problem.");
            }
        }

        internal static void RegisterCustomCards(Harmony harmony)
        {
            // Register the sigils
            RegisterCustomAbilities(harmony);

            // Register the protected metacategories
            RegisterMetacategories();

            // Update all of the old style side deck cards
            CardManager.ModifyCardList += delegate(List<CardInfo> cards)
            {
                foreach (CardInfo card in cards.Where(c => c.HasTrait(SideDeckManager.BACKWARDS_COMPATIBLE_SIDE_DECK_MARKER)))
                {
                    card.SetSideDeck(card.temple, 10);
                    card.traits.Remove(SideDeckManager.BACKWARDS_COMPATIBLE_SIDE_DECK_MARKER);
                }

                return cards;
            };

            // me trying to add mox vessels
            CardManager.New(SideDecksPlugin.CardPrefix,
                    "OrueVessel",
                    "Orue Vessel",
                    0, 1,
                    "Vessels that give blue and orange Mox Gems.")
                .SetSideDeck(CardTemple.Tech, 10)
                .SetPortrait(Resources.Load<Texture2D>("art/cards/portraits/Mox_Blue_Orange.png"))
                .SetPixelPortrait(Resources.Load<Texture2D>("art/gbc/cards/pixelportraits/Mox_Blue_Orange_Pixel.png"))
                .AddAbilities(Ability.GainGemBlue, GainGemOrange);
        }
    }
}
{
    public static class CustomCards
    {
        public static readonly List<Ability> sideDeckableAbilities = new List<Ability>() {
            Ability.GainGemOrange, GainGemGreen
        };

        private static void RegisterMetacategoriesInner()
        {
            PackManager.AddProtectedMetacategory(SideDeckManager.SIDE_DECK);
        }

        private static void RegisterMetacategories()
        {
            try
            {
                RegisterMetacategoriesInner();
            }
            catch (Exception)
            {
                SideDecksPlugin.Log.LogInfo($"Error registering pack manager exception - pack manager plugin not loaded. This is not a problem.");
            }
        }

        internal static void RegisterCustomCards(Harmony harmony)
        {
            // Register the sigils
            RegisterCustomAbilities(harmony);

            // Register the protected metacategories
            RegisterMetacategories();

            // Update all of the old style side deck cards
            CardManager.ModifyCardList += delegate(List<CardInfo> cards)
            {
                foreach (CardInfo card in cards.Where(c => c.HasTrait(SideDeckManager.BACKWARDS_COMPATIBLE_SIDE_DECK_MARKER)))
                {
                    card.SetSideDeck(card.temple, 10);
                    card.traits.Remove(SideDeckManager.BACKWARDS_COMPATIBLE_SIDE_DECK_MARKER);
                }

                return cards;
            };

            // me trying to add mox vessels
            CardManager.New(SideDecksPlugin.CardPrefix,
                    "GrengeVessel",
                    "Grenge Vessel",
                    0, 1,
                    "Vessels that give green and orange Mox Gems.")
                .SetSideDeck(CardTemple.Tech, 10)
                .SetPortrait(Resources.Load<Texture2D>("art/cards/portraits/Mox_Orange_Green.png"))
                .SetPixelPortrait(Resources.Load<Texture2D>("art/gbc/cards/pixelportraits/Mox_Orange_Green_Pixel.png"))
                .AddAbilities(Ability.GainGemOrange, GainGemGreen);
        }
    }
}